R/check_version.R
check_version.RdThis function checks if you have the latest version of the Flora e Funga do Brasil data available in a specified directory.
check_version(data_dir)A message informing whether you have the latest version of Flora e Funga do Brasil available in the data_dir
if (FALSE) { # \dontrun{
#Check if there is a version of Flora e Funga do Brasil data available in the
#current directory
check_version(data_dir = getwd())
} # }